@@ -5,6 +5,7 @@ import tqdm
 
 import pyro as pyro
 import numpy as np
+import math
 from pyro.infer.autoguide import AutoDelta
 import pyro.poutine as poutine
 import torch
@@ -93,13 +94,13 @@ def run(data, params, svi, stopping, max_it, e):
         t.refresh()
 
         loss = svi.step(**data_dict)
-        losses.append(loss / N)
+        losses.append(loss)
 
         old, new = new, loss
 
         if stopping(old, new, e):
             break
-        if np.isinf(loss):
+        if np.isinf(loss) or math.isinf(loss):
             break
 
     return losses
